@@ -44,7 +44,12 @@ pub enum PatternError {
 fn is_single_node(n: &tree_sitter::Node) -> bool {
   match n.child_count() {
     1 => true,
-    2 => n.child(1).expect("second child must exist").is_missing(),
+    2 => {
+      let c = n.child(1).expect("second child must exist");
+      // some language will have weird empty syntax node at the end
+      // see golang's `$A = 0` pattern test case
+      c.is_missing() || c.kind().is_empty()
+    }
     _ => false,
   }
 }
@@ -391,4 +396,13 @@ mod test {
     let ret = Pattern::str("123+", Tsx);
     assert!(ret.has_error());
   }
+
+  #[test]
+  fn test_bare_wildcard_in_context() {
+    let pattern =
+      Pattern::<StrDoc<_>>::contextual("class A { $F }", "property_identifier", Tsx).expect("test");
+    let cand = pattern_node("let b = 123");
+    // should it match?
+    assert!(pattern.find_node(cand.root()).is_some());
+  }
 }
